Datasets
========

load_sample
-----------
.. currentmodule:: bcselector.datasets

.. autofunction:: load_sample

load_hepatitis
--------------
.. currentmodule:: bcselector.datasets

.. autofunction:: load_hepatitis